package main

import (
	"GofileScrapper/api"
	"GofileScrapper/misc"
	"GofileScrapper/structs"
	"fmt"
	"sync"
	"time"
)

type OldContent struct {
	ID      string
	Retried int
}

func run(guest structs.Guest) []structs.Content {
	var contents []structs.Content

	old := OldContent{
		ID:      misc.GetRandomContent(),
		Retried: 0,
	}

	for i := 0; i < misc.MaxPerThread; i++ {
		if old.Retried == misc.MaxRetries {
			old = OldContent{
				ID:      misc.GetRandomContent(),
				Retried: 0,
			}
		}

		content, err := api.GetContent(guest, old.ID)

		if err != nil {
			misc.Logger.Error().Msg(err.Error())
		} else {
			if content.Status == "error-rateLimit" {
				old.Retried += 1
				misc.Logger.Info().Msg(fmt.Sprintf("Rate limit reached, waiting %ds...", misc.MaxRetries))
				time.Sleep(5 * time.Second)
			} else {
				contents = append(contents, content)
			}
		}
	}

	return contents
}

func main() {
	var guests []structs.Guest

	for i := 0; i < misc.GuestCount; i++ {
		guest, err := api.GetGuest()
		if err != nil {
			misc.Logger.Error().Msg(err.Error())
		} else {
			guests = append(guests, guest)
		}
	}

	results := make(chan structs.Content)

	var wg sync.WaitGroup

	for _, guest := range guests {
		wg.Add(1)
		go func(guest structs.Guest) {
			defer wg.Done()
			for _, content := range run(guest) {
				results <- content
			}
		}(guest)
	}

	go func() {
		wg.Wait()
		close(results)
	}()

	for content := range results {
		fmt.Println("Content:", content)
	}
}
